@@ -1,9 +1,14 @@
 """Utilities"""
-import resource
 import datetime
 
 from .datamessage import PubSubDataMessage
 
+try:
+    import resource
+
+    MODRESOURCE_AVAILABLE = True
+except ImportError:
+    MODRESOURCE_AVAILABLE = False
 
 RESOURCE_KEYS = (
     "ru_utime",
@@ -27,10 +32,11 @@ RESOURCE_KEYS = (
 
 def create_heartbeat_message() -> PubSubDataMessage:
     """Create a heartbeat message"""
-    rudata = resource.getrusage(resource.RUSAGE_SELF)
     msg = PubSubDataMessage(b"HEARTBEAT")
     msg.data["systemtime"] = datetime.datetime.utcnow().isoformat() + "Z"
-    msg.data["resources"] = {}
-    for key in RESOURCE_KEYS:
-        msg.data["resources"][key[3:]] = getattr(rudata, key)
+    if MODRESOURCE_AVAILABLE:
+        rudata = resource.getrusage(resource.RUSAGE_SELF)
+        msg.data["resources"] = {}
+        for key in RESOURCE_KEYS:
+            msg.data["resources"][key[3:]] = getattr(rudata, key)
     return msg
